****************************
The sherpa.optmethods module
****************************

.. currentmodule:: sherpa.optmethods

.. automodule:: sherpa.optmethods

  .. rubric:: Classes
              
  .. autosummary::
     :toctree: api

     OptMethod
     LevMar
     NelderMead
     MonCar
     GridSearch

Class Inheritance Diagram
=========================

.. inheritance-diagram::  OptMethod LevMar NelderMead MonCar GridSearch
   :parts: 1
             
